/*

This example shows how the noise generator could generate landscapes to show elevation.

It generates a noise matrix with a size and width of 30.  It randomizes the matrix,
and uses it to determine the elevation of turfs on the map.  The water level is
set and 2, and the amplitude of the noise is 5.  So the matrix generates
noise for each turf 1-5, and if it is less than 2, it is water.
*/

world
	maxx = 30
	maxy = 30
	maxz = 1
mob/verb/GenerateElevation()
	// Create a new matrix
	var/Noise/height = new(30, 30)
	// Set the frequency and amplitude
	height.frequency = 8
	height.amplitude = 5
	height.smoothness = 2
	// Randomize the matrix.  You could optionally pass a random seed to use as
	// the arguement.
	height.Randomize()
	// Now, we read the data from the matrix and apply it to our map!
	for(var/turf/t in block(locate(1,1,1),locate(30,30,1)))
		t.icon = 'demo.dmi'
		// The icon_state will be 1 - 5, because of the amplitude.
		t.icon_state = "[round(height.Noise(t.x,t.y))]"
		// We set our water level to 2, so anything below that will show up as water!
		if(height.Noise(t.x,t.y)<=2)
			t.icon_state = "water"